@@ -62,7 +62,7 @@ About.prototype.beginEvent = function() {
 
     // init plugin view:
     var textBrowser = dialog.findChild("PluginsText");
-    WidgetFactory.initTextBrowser(textBrowser, this, "openUrl");
+    WidgetFactory.initTextBrowser(textBrowser, QDesktopServices.openUrl);
     this.initAboutPlugins(textBrowser);
 
     dialog.windowTitle = qsTr("About %1").arg(this.applicationName);
@@ -72,16 +72,16 @@ About.prototype.beginEvent = function() {
 
     // init about view:
     textBrowser = dialog.findChild("AppText");
-    WidgetFactory.initTextBrowser(textBrowser, this, "openUrl");
+    WidgetFactory.initTextBrowser(textBrowser, QDesktopServices.openUrl);
     this.initAboutApp(textBrowser);
 
     // init scripts view:
     textBrowser = dialog.findChild("ScriptsText");
-    WidgetFactory.initTextBrowser(textBrowser, this, "openUrl");
+    WidgetFactory.initTextBrowser(textBrowser, QDesktopServices.openUrl);
     this.initAboutScripts(textBrowser);
 
     textBrowser = dialog.findChild("CreditsText");
-    WidgetFactory.initTextBrowser(textBrowser, this, "openUrl");
+    WidgetFactory.initTextBrowser(textBrowser, QDesktopServices.openUrl);
     this.initCredits(textBrowser);
 
     // init system view:
@@ -93,7 +93,7 @@ About.prototype.beginEvent = function() {
     this.initAboutLicenses(textBrowser);
 
     dialog.exec();
-    dialog.destroy();
+    destr(dialog);
     EAction.activateMainWindow();
 };
 
@@ -158,8 +158,8 @@ About.prototype.initAboutApp = function(textBrowser) {
             + "<p/>"
             + "<p>" + qsTr("All brand or product names are trademarks or registered trademarks of their respective holders.") + "</p>"
             + "<p/>"
-            + "<p>© 2011-2022 RibbonSoft, GmbH.</p>"
-            + "<p>" + qsTr("Portions of this software © %1 The Qt Company Ltd.").arg("2008-2022") + "</p>"
+            + "<p>© 2011-2024 RibbonSoft, GmbH.</p>"
+            + "<p>" + qsTr("Portions of this software © %1 The Qt Company Ltd.").arg("2008-2024") + "</p>"
             + "<p>" + qsTr("Qt ships with QCAD under the <a href='%1'>LGPL Open Source license</a> which confers various rights to you as the user, including the right to recompile the Qt libraries for your platform. To do that follow the <a href='%2'>documentation shown on the Qt website</a>.").arg("https://www.gnu.org/licenses/lgpl-3.0.html").arg("https://doc.qt.io/qt-5/build-sources.html") + "</p>"
             + "<p>" + qsTr("The program is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.") + "</p>"
             + "<p/>"
@@ -205,7 +205,7 @@ About.prototype.initAboutPlugins = function(textBrowser) {
 
             // plugin about info:
             text = pluginInfo.get("Name", qsTr("No information available"));
-            html += this.getTableRow(qsTr("Plugin:"), "<b>" + Qt.escape(text) + "</b>", false);
+            html += this.getTableRow(qsTr("Plugin:"), "<b>" + RS.escape(text) + "</b>", false);
 
             // overrides:
             if (isNull(maxPri) || pri>maxPri) {
@@ -415,7 +415,7 @@ About.prototype.initCredits = function(textBrowser) {
 
 About.prototype.getTableRow = function(text1, text2, escape) {
     if (isNull(escape) || escape!==false) {
-        text2 = Qt.escape(text2);
+        text2 = RS.escape(text2);
     }
 
     return "<tr><td width='25%' valign='top'>%1 </td><td width='75%'>%2</td></tr>".arg(text1).arg(text2);
@@ -495,8 +495,13 @@ About.prototype.initAboutSystem = function(textEdit) {
     text += "\nNegative sign: " + sysloc.negativeSign();
     text += "\nPositive sign: " + sysloc.positiveSign();
     text += "\nText direction: " + sysloc.textDirection();
-    text += "\nSystem codec: " + QTextCodec.codecForLocale().name();
-
+    if (RSettings.getQtVersion() > 0x060000) {
+        // TODO #qt6: prints number not name
+        text += "\nSystem codec: " + QStringConverter.nameForEncoding(QStringConverter.System);
+    }
+    else {
+        text += "\nSystem codec: " + QTextCodec.codecForLocale().name();
+    }
     text += "\n";
     text += "\nArguments: " + RSettings.getOriginalArguments();
 
@@ -635,10 +640,5 @@ About.prototype.initAboutLicenses = function(textBrowser) {
     html += "</body>";
     html += "</html>";
     textBrowser.setHtml(html);
-    WidgetFactory.initTextBrowser(textBrowser, this, "openUrl");
+    WidgetFactory.initTextBrowser(textBrowser, QDesktopServices.openUrl);
 };
-
-About.prototype.openUrl = function(url) {
-    QDesktopServices.openUrl(url);
-};
-
